import setuptools

setuptools.setup(name='shoppon',
                 version='0.1.2',
                 description='Demo code',
                 url='https://github.com/shoppon/shoppon/',
                 author='Shoppon',
                 author_email='shoppon@gmail.com',
                 license='MIT',
                 packages=setuptools.find_packages(),
                 zip_safe=False)
